@@ -13,7 +13,7 @@ def register_models():
     models = apps.get_models()
     
     for model in models:
-        print(model)
+        print(isinstance(model(),BaseModel))
         if isinstance(model(),BaseModel):
             try:
                 if model.__name__ not in exclude_models:
@@ -32,4 +32,5 @@ def register_models():
                                 urlpatterns += model().build_generics_urls_crud()
             except:
                 pass
+    print(urlpatterns)
     return urlpatterns
\ No newline at end of file
